==> inSilicoDb_2.0.1.tar.gz: inSilicoDb/man/getDatasetList.Rd <==
\name{getDatasetList}
\alias{getDatasetList}
\title{Get list of all available dataset identifiers}
\description{
	Get list of all available dataset identifiers that satisfy all specified constraints (see Arguments).
}
\usage{
getDatasetList(...);
}
\arguments{
 \item{...}{Optional arguments can be passed to the function for more specific requests:
	\describe{
  	\item{\code{platform}}{The platform of the chip on which a measurement was done.
A platform is identified by its GEO accession code. If specified, only datasets on the given platform are returned.}
  	\item{\code{norm}}{Type of normalization to use when pre-processing a dataset. Possible values: "ORIGINAL", "FRMA"[1], "SCAN"[2] or "UPC"[3]. If specified, only datasets for which the given preprocessed data is available are returned.}
  	\item{\code{query}}{If specified, only datasets for which the query keyword appears in either the title or description of the dataset. typical example queries are 'Thyroid Cancer', 'Primary vs Metastasis', 'p53', etc.}
 	\item{\code{curated}}{If curated = TRUE is specified, only manually curated datasets will be returned. }
	}
  }
}
\value{
A list of dataset identifiers.
}
\examples{
length(getDatasetList());
## 7167
length(getDatasetList(platform = "GPL570"));
## 2717
length(getDatasetList(platform = "GPL570", norm = "FRMA"));
## 2406
length(getDatasetList(platform = "GPL570", norm = "FRMA", 
                      query = "Thyroid Cancer"));
## 5
getDatasetList(platform = "GPL570", norm = "FRMA", 
               query = "Thyroid Cancer");
## [1] "GSE6004"  "GSE7307"  "GSE32161" "GSE29265" "GSE2109" 
}
\seealso{
Use \code{\link{getDatasetPlatformList}} for the same functionality with a list of (dataset, platform) tuples as result.
}
\references{
[1] MN. McCall, BM. Bolstad, and RA. Irizarry, Frozen Robust Multi-Array Analysis (fRMA),
  \emph{Biostatistics}, vol. 11, no. 2, pp. 242-253 , 2008.
  
[2] SR. Piccolo, Y. Sun, JD. Campbell, ME. Lenburg, AH. Bild, and WE. Johnson, A single-sample microarray
  normalization method to facilitate personalized-medicine workflows, \emph{Genomics}, vol. 100, no. 6, pp. 337-344, 2012.
  
[3] SR. Piccolo, MR. Withers, OE. Francis, AH. Bild, and WE. Johnson, Multi-platform single-sample estimates of transcriptional activation, \emph{Proceedings of the National Academy of Sciences of the United States of America}, vol. 110, no. 44, pp. 17778-17783, 2013.
}

==> inSilicoDb_2.4.1.tar.gz: inSilicoDb/man/getDatasetList.Rd <==
\name{getDatasetList}
\alias{getDatasetList}
\title{Get list of all available dataset identifiers}
\description{
	Get list of all available dataset identifiers that satisfy all specified constraints (see Arguments).
}
\usage{
getDatasetList(...);
}
\arguments{
 \item{...}{Optional arguments can be passed to the function for more specific requests:
	\describe{
  	\item{\code{platform}}{The platform of the chip on which a measurement was done.
A platform is identified by its GEO accession code. If specified, only datasets on the given platform are returned.}
  	\item{\code{norm}}{Type of normalization to use when pre-processing a dataset. Possible values: "ORIGINAL", "FRMA"[1], "SCAN"[2]. If specified, only datasets for which the given preprocessed data is available are returned.}
  	\item{\code{query}}{If specified, only datasets for which the query keyword appears in either the title or description of the dataset. typical example queries are 'Thyroid Cancer', 'Primary vs Metastasis', 'p53', etc.}
 	\item{\code{curated}}{If curated = TRUE is specified, only manually curated datasets will be returned. }
	}
  }
}
\value{
A list of dataset identifiers.
}
\examples{
length(getDatasetList());
## 7167
length(getDatasetList(platform = "GPL570"));
## 2717
length(getDatasetList(platform = "GPL570", norm = "FRMA"));
## 2406
length(getDatasetList(platform = "GPL570", norm = "FRMA", 
                      query = "Thyroid Cancer"));
## 5
getDatasetList(platform = "GPL570", norm = "FRMA", 
               query = "Thyroid Cancer");
## [1] "GSE6004"  "GSE7307"  "GSE32161" "GSE29265" "GSE2109" 
}
\seealso{
Use \code{\link{getDatasetPlatformList}} for the same functionality with a list of (dataset, platform) tuples as result.
}
\references{
[1] MN. McCall, BM. Bolstad, and RA. Irizarry, Frozen Robust Multi-Array Analysis (fRMA),
  \emph{Biostatistics}, vol. 11, no. 2, pp. 242-253 , 2008.
  
[2] SR. Piccolo, Y. Sun, JD. Campbell, ME. Lenburg, AH. Bild, and WE. Johnson, A single-sample microarray
  normalization method to facilitate personalized-medicine workflows, \emph{Genomics}, vol. 100, no. 6, pp. 337-344, 2012.
}
